# PySh

A Python package that mimics the Oh-My-ZSH shell. This package creates a colorful ZSH prompt.

## Installation
To install PySh onto your system, run `pip install python-pysh` in your terminal.
If the command errors out, try `pip install git+git://github.com/Python3-8/python-pysh`.
If the second command errors out too, clone the GitHub repo for PySh and move the `pysh` folder to  
your Python `site-packages` directory.

## Usage

The following command on your terminal will run the PySh shell.

```sh
$ pysh
```

## Contact
You may contact the developer of PySh at: pranav.pooruli@gmail.com
